@@ -96,11 +96,11 @@ __MERCHANT_CUSTOMER_REDEMPTION_SCHEMA = {
                             bigquery.SchemaField('Key', 'STRING'),
                             bigquery.SchemaField('CustomerKey', 'STRING'),
                             bigquery.SchemaField('MerchantKey', 'STRING'),
-                            bigquery.SchemaField('RedeemOutlet', 'STRING'),
+                            bigquery.SchemaField('RedeemedOutlet', 'STRING'),
                             bigquery.SchemaField('TransactionId', 'STRING'),
-                            bigquery.SchemaField('RedeemAmount', 'FLOAT64'),
+                            bigquery.SchemaField('RedeemedAmount', 'FLOAT64'),
                             bigquery.SchemaField('RewardFormat', 'STRING'),
-                            bigquery.SchemaField('VoucherKeysList', 'STRUCT'),
+                            bigquery.SchemaField('VoucherKey', 'STRING'),
                             bigquery.SchemaField('RedeemedDateTime', 'DATETIME'),
                             bigquery.SchemaField('Reverted', 'BOOLEAN'),
                             bigquery.SchemaField('RevertedDateTime', 'DATETIME'),
