@@ -17,7 +17,7 @@ transaction_analytics_data_bp = Blueprint('transaction_analytics_data_bp', __nam
                                  static_folder='static',
                                  url_prefix='/analytics/transaction')
 
-logger = logging.getLogger('query')
+logger = logging.getLogger('analytics')
 
 query_transaction_data_api = Api(transaction_analytics_data_bp)
 
@@ -59,14 +59,14 @@ class CustomerTransactionQueryBase(QueryBaseResource):
 class QueryAllCustomerTransactionByYearMonth(CustomerTransactionQueryBase):
     def prepare_query(self, **kwrgs):
         
-        year_month_from   = kwrgs.get('year_month_from')
-        year_month_to     = kwrgs.get('year_month_to')
+        date_range_from   = kwrgs.get('date_range_from')
+        date_range_to     = kwrgs.get('date_range_to')
         
         where_condition  = ''
         
-        if year_month_from and year_month_to:
-            where_condition = "WHERE _TABLE_SUFFIX BETWEEN '{year_month_from}' and '{year_month_to}'".format(year_month_from=year_month_from, 
-                                                                                                         year_month_to=year_month_to)
+        if date_range_from and date_range_to:
+            where_condition = "WHERE _TABLE_SUFFIX BETWEEN '{date_range_from}' and '{date_range_to}'".format(date_range_from=date_range_from, 
+                                                                                                         date_range_to=date_range_to)
         
         query = '''
             SELECT FORMAT_DATETIME('%Y-%m', TransactDateTime) as date_range, sum(TotalTransactAmount) as sumTransactAmount, count(*) as transactionCount
@@ -91,16 +91,16 @@ class QueryAllCustomerTransactionByYearMonth(CustomerTransactionQueryBase):
 class QueryMerchantCustomerTransactionByYearMonth(CustomerTransactionQueryBase):
     def prepare_query(self, **kwrgs):
         account_code      = kwrgs.get('account_code')
-        year_month_from   = kwrgs.get('year_month_from')
-        year_month_to     = kwrgs.get('year_month_to')
+        date_range_from   = kwrgs.get('date_range_from')
+        date_range_to     = kwrgs.get('date_range_to')
         
         account_code = account_code.replace('-','')
         
         where_condition  = ''
         
-        if year_month_from and year_month_to:
-            where_condition = "WHERE _TABLE_SUFFIX BETWEEN '{year_month_from}' and '{year_month_to}'".format(year_month_from=year_month_from, 
-                                                                                                         year_month_to=year_month_to)
+        if date_range_from and date_range_to:
+            where_condition = "WHERE _TABLE_SUFFIX BETWEEN '{year_month_from}' and '{year_month_to}'".format(date_range_from=date_range_from, 
+                                                                                                         date_range_to=date_range_to)
         
         query = '''
             SELECT FORMAT_DATETIME('%Y-%m', TransactDateTime) as date_range, sum(TotalTransactAmount) as sumTransactAmount, count(*) as transactionCount
